.\" Copyright (c) 1990 The Regents of the University of California.
.\" All rights reserved.
.\"
.\" This code is derived from software contributed to Berkeley by
.\" John B. Roll Jr. and the Institute of Electrical and Electronics
.\" Engineers, Inc.
.\"
.\" %sccs.include.redist.man%
.\"
.\"	%W% (Berkeley) %G%
.\"
.TH XARGS 1 "%Q%"
.UC 7
.SH NAME
xargs \- construct argument list(s) and execute utility.
.SH SYNOPSIS
.ft B
xargs [\-t] [[\-x] \-n number] [\-s size] [utility [arg ...]]
.ft R
.SH DESCRIPTION
The
.I xargs
utility reads space, tab, newline and end-of-file delimited arguments
from the standard input and executes the specified
.I utility
with them as arguments.
.PP
The utility and any arguments specified on the command line are given
to the
.I utility
upon each invocation, followed by some number of the arguments read
from standard input.
The
.I utility
is repeatedly executed until standard input is exhausted.
.PP
Spaces, tabs and newlines may be embedded in arguments using single (`` ' '')
or double (``"'') quotes or backslashes (``\e'').
Single quotes escape all non-single quote characters, excluding newlines,
up to the matching single quote.
Double quotes escape all non-double quote characters, excluding newlines,
up to the matching double quote.
Any single character, including newlines, may be escaped by a backslash.
.PP
The options are as follows:
.TP
\-n number
Set the maximum number of arguments taken from standard input for each
invocation of the utility.
An invocation of
.I utility
will use less than
.I number
standard input arguments if the number of bytes accumulated (see the
.I \-s
option) exceeds the specified
.I size
or there are fewer than
.I number
arguments remaining for the last invocation of
.IR utility .
The current default value for
.I number
is 5000.
.TP
\-s size
Set the maximum number of bytes for the command line length provided to
.IR utility .
The sum of the length of the utility name and the arguments passed to
.I utility
(including NULL terminators) will be less than or equal to this number.
The current default value for
.I size
is ARG_MAX - 2048.
.TP
\-t
Echo the command to be executed to standard error immediately before it
is executed.
.TP
\-x
Force
.I xargs
to terminate immediately if a command line containing
.I number
arguments will not fit in the specified (or default) command line length.
.PP
If no
.I utility
is specified,
.IR echo (1)
is used.
.PP
Undefined behavior may occur if
.I utility
reads from the standard input.
.PP
The
.I xargs
utility exits immediately (without processing any further input) if a
command line cannot be assembled,
.I utility
cannot be invoked, an invocation of the utility is terminated by a signal
or an invocation of the utility exits with a value of 255.
.PP
The
.I xargs
utility exits with a value of 0 if no error occurs.
If
.I utility
cannot be invoked,
.I xargs
exits with a value of 127.
If any other error occurs,
.I xargs
exits with a value of 1.
.SH "SEE ALSO"
.IR echo (1),
.IR find (1)
.SH STANDARDS
The
.I xargs
utility is expected to be POSIX 1003.2 compliant.
